Fight © Trolls | Do your duty, result is a bonus
Description: Do your duty, result is a bonus

##### Guardaley | Voltage

# Concerned about the copyright trolling situation in the state, Oregon federal judge wants to restrict trolls’ free reign

Oregon has been suffering from the copyright trolling abuse for a couple of years. It is actually a single attorney — Carl Crowell — who has been terrorizing his fellow citizens on behalf of the German piracy monetizing outfit. Mr. Crowell is a crafty attorney and he is known for constantly inventing new ways of harassing hapless file-sharers (and innocents alike).

US Federal Judge
Michael W. Mosman

Out of his recent sleazes the most disturbing is the practice of deposing putative defendants prior to amending the complaint (replacing “John Doe” with an actual name). Since the majority of the targeted are laypeople of modest means, they tend not to spend money on attorneys, so they make a grave mistake of agreeing to be deposed without a lawyer. I don’t think it makes sense to explain why it is a real problem. Copyright trolls are known to be machos when dealing with laypeople (in contrast, when confronted by experienced attorneys, the trolls usually run away).

Apparently, the judges are not deaf and blind, and they are increasingly concerned with both the sheer volume of docket-clogging lawsuits, and the troll lawyers’ overreach. Federal Judge Michael Mosman recently drafted a standing order urging putative defendants to seek legal help.

> For that, The Court has established a panel of lawyers who are willing to provide assistance and advice to subscribers in these lawsuits at no charge for up to 3 hours.

Continue Reading

Published on: January 15, 2016January 20, 2016 Author: SJD

##### Guardaley | Lipscomb | X-Art

# Does Malibu Media leak its porn before the release?

It was proven beyond any doubt that Prenda seeded their smut on Bittorent to entrap hapless file-sharers. Given the striking similarities between Prenda and Guardley-driven copyright shakedown outfits, including Lipscomb/X-Art/Malibu Media, it wouldn’t be unreasonable to believe that the Karlsruhe-Miami-Malibu cartel’s hands are not so clean in this respect either. Indeed, numerous defense attorneys asserted that Malibu either seeds their porn itself, or someone does it with its blessing. Even Jordan Rushie, before he started doing errands for Lipscomb, suggested that

> When considering litigating the “swarm theory,” Malibu was faced with the prospect of dozens of defendants, joined in their common defense against the plaintiff, with an initial seeder who very well may have had a license to publish the works to BitTorrent or elsewhere. [FN: Malibu’s investigation company, IPP, Ltd., was previously called Guardaley, Ltd. While it had that name, it was accused of being the seeder for swarms its customers later such over.]

> […]

> As Malibu does freely distribute the relevant films, it is entirely possible, if not most likely, that the initial seeder had permission to distribute the files via BitTorrent. [FN: Or it was Malibu’s own agent.] If he or she did not, it is entirely likely that a participant in the swarm, from whom Doe 13 received the file, may have had such permission.

Attorneys in these cases are generally protected by the litigation privilege that shields them from defamation claims. I don’t have such luxury. Therefore, I expressly state that I don’t possess enough evidence to affirmatively accuse X-Art, Lipscomb, and their unlicensed “investigator” Guardaley/IPP/Excipio of deliberately leaking their movies.

However, there are facts that at very least should make judges and juries (if it ever comes that far, which I doubt) extremely skeptical when they hear plaintiff’s laments about evil pirates destroying their fine business, and the “Unclean Hands Doctrine” defense may actually work.

The facts below are mind-boggling. I analyzed the exact timestamps when X-Art’s smut first appeared on the Pirate Bay. Assuming that X-Art posts new videos at 21:00 PDT¹ a day prior to the sated publication date, I found at least 50 instances when the porn hit the Pirate Bay earlier than it appeared on x-art.com. Some movies might be released earlier, so I cannot vouch for some marginal cases, where a Pirate Bay upload took place a couple of hours before 21:00, yet many instances below cannot be explained this way. For example, how can X-Art explain that their 02/15/2013 flick “Afternoon Picnic”

became available on the Pirate Bay almost 5 days prior to the release?

Continue Reading

Published on: January 10, 2016January 14, 2016 Author: SJD

##### Guardaley | Lipscomb | X-Art

# Malibu Media case management conference in CAND: notes and thoughts

“Barely legal” porn copyright trolls Guardaley | Excipio | Keith Lipscomb | X-Art | Malibu Media (the beast has many heads and names) re-infested California with 70+ individual lawsuits in September after a three-year hiatus.

In a significant move, all these cases, initially scattered among many judges, were reassigned to a single judge — William Alsup — on 9/29. Three weeks later the judge allowed ex-parte discovery and set the initial case management conference, which took place today.

EFF’s intern Jack Bussell was in the courtroom and he was kind to share his notes:

US Federal Judge
William H. Alsup

> There were two attorneys for Malibu Media, Brenna Erlbaum and a man whose name I didn’t catch¹.

> Malibu Media mentioned Comcast and no other ISPs. They are currently receiving notices of representation and settlement offers. They asked for ISP compliance between December 11 and January 4. Malibu Media has not yet served any defendant. The judge had previously ordered that the last day for service would be January 7 to January 25.

> Malibu Media stated that no one who they are going after would have infringed fewer than 20 works. The judge asked how Malibu Media identifies an infringer. Malibu Media responded that Excipio monitors the torrent swarm and downloads, but not uploads, the works. The judge asked how Malibu Media could be sure those persons actually infringed. Malibu Media responded that they would engage in depositions and building internet profiles. One example of a profile they offered was if the infringement stopped for a week and that coincided with a week the alleged infringer was on vacation.

> Malibu Media stated that they are prepared to go to trial and meet their burden of proof. However, they acknowledged that most people settle and most settle early. They also stated they expect more pushback in “tech-savvy” Northern California.

> Malibu Media has another case management conference scheduled for March 3 at 1:30, on 70 cases.

> Judge Alsup said the settlement offers must be reasonable, not to multiply statutory damages “by every minute of the day,” and not to “use the federal court as a bludgeon.”

It is sad that the young Brenna resorted to telling fables to the judge: the proposition that “they are prepared to go to trial and meet their burden of proof” is disingenuous to put it mildly. Out of almost 5,000 cases filed in 13 states over the last three years, exactly zero proceeded to jury trial. We have been hearing the “we are not afraid of jury” song for years, yet every single case was either settled or dismissed. Notably, the majority of cases, where defendants seriously pushed back, ended up in walk-away settlements (no money changed hands): so much for the “impeccable evidence” and “eagerness to go to trial.” These cases are simply not designed to go to trial. Only dishonest, intellectually lazy or stupid would claim otherwise.

With all respect to Judge Alsup, “using the federal court as a bludgeon” is exactly Malibu Media’s modus operandi, and these people have been using courts as both bludgeon and money press for years.

I was going to stop here, but since Comcast is already sending out emails, and new victims are searching for “Brenna Erlbaum,” I felt compelled to share some thoughts.

Continue Reading
Published on: November 20, 2015November 21, 2015 Author: SJD

##### Guardaley | Lipscomb | X-Art

# Defendant: Malibu Media is a scam (in a literal meaning of this word)

Once in a while we witness new defense attorneys appear on the scene, and they bring fresh ideas. In Malibu Media v. Domingo Rodriguez (ILND 15-cv-03610), a shakedown lawsuit brought by the Miami Troll Center via its marionette, a chronic liar Mary K. Schulz, the defendant hired an experienced lawyer from Chicago, Andy Norman.

Today Mr. Norman filed the defendant’s Answer, Affirmative Defenses and Counterclaims. This is the first time I saw the claim that Malibu Media’s conduct violates Illinois Consumer Fraud and Deceptive Business Practices Act.

> […] plaintiff’s scam is “unfair” as contemplated by § 2 of the Act. See, Robinson v. Toyota Motor Credit Corp., 201 Ill. 2d 403, 418 (2002). In Robinson the Illinois Supreme Court ruled that there are three ways to prove unfairness under the Act. In fact, plaintiff’s scam is unfair under each of the three tests. First, plaintiff’s practice of implementing its scam against hundreds of unwary internet consumers “offends public policy.” Second, it is it is “immoral, unethical, oppressive, or unscrupulous.” Finally, it “causes substantial injury to consumers.”

The word “scam” appears in the complaint 24 times, and those are not figurative uses.

I agree with such characterization.

According to Mr. Norman’s LinkedIn page,

> Since 1983 he has handled more than 75 class action cases. He has counseled thousands of consumers and business owners regarding fraud, contract, warranty and other disputes, and many pastors and Christians regarding religious and civil rights.

…so this attorney most definitely knows what he is talking about.
Continue Reading

Published on: November 16, 2015December 22, 2015 Author: SJD

##### Guardaley | Lipscomb | X-Art

# Malibu Media expert’s report deserves some scrutiny

Last week I wrote about a motion for summary judgement filed by the defendant (via his attorney Cynthia Conlin) in a closely watched and eventful case Malibu Media v Robert Dare (FLSD 14-cv-61957). This motion was backed by a report produced by the defendant’s own expert, Tom Parker. The report suggested that the German evidence was incomplete and misleading and didn’t back the claim that the defendant downloaded/shared the entire videos. In addition, the expert asserted that anyone in close proximity to the defendant’s house could piggyback on his wi-fi connection to torrent XArt’s pornography.

The plaintiff had up to 10/28 to rebut the report. Instead, Malibu fired its own motion for summary judgement. Among numerous exhibits to this motion, a couple can be counted as a rebuttal attempt. A very interesting transcript of Tom Parker’s deposition deserves a separate analysis, and I’ll get back to it in the coming days. Today’s post is about another document: a very strange “Report on the probability that two Americans live next to each other and both use Bittorent and the Bittorent client Transmission,” prepared by Dr. Dan Sarel who is an associate professor of marketing in the School of Business Administration at the University of Miami.

This report’s aim was to rebut Tom Parker’s suggestion that accessing wi-fi by a neighbor was possible and plausible. Dr. Sarel’s argument was largely based on the fact that the Germans determined that the alleged infringer had used a relatively rare Bittorent client, Transmission — the very same client the defendant admitted to own. The expert argued that such a coincidence is unlikely:

> Subject to the assumptions and limitations set forth below, I conclude the probability that two Americans live next to each and both use BitTorrent and the BitTorrent client “Transmission” is 1 out of 37,679.

Dr. Sarel was paid a $2,500 fee for what, in my opinion, is a half-assed argument at best. Read the report and scroll down: I’ll try to explain why I think it is misleading and doesn’t rebut the defendant expert’s report at all.
Continue Reading

Published on: November 1, 2015November 9, 2015 Author: SJD

##### Guardaley | Lipscomb | X-Art

# Defendant’s expert witness report suggests that Malibu Media’s investigators doctored evidence

On 10/20/2015 Cynthia Conlin, the defense attorney in Malibu Media v Robert Dare (FLSD 14-cv-61957), filed a powerful motion for summary judgment. The motion is a worthwhile read: it tells a typical story of an attempt to shake down a citizen over illegally filmed teen pornography — despite a total absence of evidence.

As it happened in many other Malibu cases, no direct evidence of infringement — either admission of wrongdoing or traces of plaintiff’s smut — was found here. Alleged Bittorent transactions recorded by foreign players are not enough: this type of indirect “evidence” is unlikely to fly in US courts. This is the point where a reasonable party offers at least a walk-away to the defendant.

Yet we deal with Keith Lipscomb’s enormous hubris here. Instead of letting a defendant go, he usually unties his magic bag of tricks and pulls out some painfully familiar tactics: delays, incoherent depositions aimed at catching the defendant in some sort of a discovery violation or perjury, delays, threatening to depose neighbors, accusations of spoliation of evidence, hunt for ephemeral computers and hard drives that were allegedly hidden from the plaintiff, delays, fishing trips to ISPs, and so on…

US Federal Judge
James I. Cohn

No surprise that many items from this list found their way to this case. At least one trick failed though: on 10/14 the troll attempted to extend discovery deadline to depose Comcast and to compel the defendant to produce allegedly undisclosed computer. Judge James Cohn disagreed:

> Plaintiff’s Second Motion for Extension of Time Within Which to Complete Discovery and Motion to Compel Production of Newly Disclosed Computer. Plaintiff has not shown good cause for the requested extension. The attached discovery materials indicate that Defendant objected to the breadth of Plaintiff’s discovery requests and the record shows that Plaintiff did not move to compel. Plaintiff has not shown that Defendant lied about the existence of the “newly disclosed computer” referenced in the motion. Further, Plaintiff’s inability to depose Comcast’s corporate representative during the nearly seven months allowed for discovery does not constitute good cause for an extension.

Fed up with this circus aimed solely at delaying the proceedings in this unwinnable lawsuit — in a hope that the defendant would give up and pay, attorney Conlin decided that it was the right time to ask the judge for a summary judgement:
Continue Reading

Published on: October 25, 2015November 2, 2015 Author: SJD

##### Not so serious

# Bloody paralegals!

| If you mention a paralegal on the first page of the response to an OSC, by the last page he/she absolutely must be fired.
| Chekhov’s Principle for Lawyers

On a hot and humid morning of August 6, 2015 Keith Lipscomb came to his Miami office and found a very unpleasant document on his desk:

> The Plaintiff is directed to show cause by a written response filed within eleven (11) days why this case should not be dismissed pursuant to Local Rule 3.10 for lack of prosecution due to the non-filing of a Case Management Report within the time prescribed by Local Rule 3.05. FAILURE TO TIMELY RESPOND TO THIS ORDER WILL RESULT IN DISMISSAL WITHOUT FURTHER NOTICE.

> DONE AND ORDERED in Chambers in Tampa, Florida, on August 6, 2015.

> Elizabeth Kovachevich
> United States District Judge

“What? Dismissal?” bellowed Lipscomb, “No way! We only started shaking down this defendant. We didn’t even call all his neighbors yet — to tell them about the “barely legal” porn illegally produced in Malibu that this guy likes to watch… But how did we manage to miss the deadline? Must be paralegals! Damn paralegals! Danny, Emilie, Jessica, bring me the paralegal!”

And they brought him the paralegal.

And Keith fired the paralegal:

> Undersigned appreciates Your Honor’s desire to expeditiously move cases toward their final resolution and sincerely apologizes for Plaintiff’s failure to file a Case Management Report within the time prescribed by Local Rule 3.05. To explain, on May 14, 2015 Plaintiff filed a waiver of service. As such, pursuant to Local Rule 3.05, the Case Management Report was due on July 13, 2015. However, the deadline was not calendared, and Plaintiff inadvertently missed this deadline. The paralegal tasked with calendaring this deadline failed to do so. This paralegal has since been fired.

And Keith was so anxious, so anxious that he lost 10 pounds. And he totally forgot to file that bloody Case Management Report. A grimace of pain on Keith’s face when he read another Order to Show Cause on 9/28/2015 was authentic:

> The Plaintiff is directed to show cause by a written response filed within eleven (11) days why this case should not be dismissed pursuant to Local Rule 3.10 for lack of prosecution due to the non-filing of a Case Management Report within the time prescribed by Local Rule 3.05. FAILURE TO TIMELY RESPOND TO THIS ORDER WILL RESULT IN DISMISSAL WITHOUT FURTHER NOTICE.

> DONE AND ORDERED in Chambers in Tampa, Florida, on September 28, 2015.

> Elizabeth Kovachevich
> United States District Judge

“Not again! I can’t even… Damn paralegals! Danny, Emilie, Jessica, bring me the paralegal! There will be blood! Oh how I’m angry!”

“Umm, Keith, you fired them all, there is only one left, and if you let her go, who will sing your favorite We are not Prenda lullaby?” Jessica coughed.

“Maybe you should try and call young Yousef from Columbus (today is the Columbus Day, ha-ha!): he manages to exit such situations all the time. The Internet Hate Group calls him Yousef ‘Show Cause’ Faroniya,” suggested Danny passing Keith a glass of water.

“OK, let’s do it,” sighed Keith, “Emilie: since you write all the motions he files, you should know his phone number.”

###### Ring-ring

“This is Yousef Faroniya, Esquire. “

“Hey, Yousef, this is Keith Lipscomb. Glad you answered: that you don’t pickup the phone is bulls—. It’s told by people who don’t have a clue what the hell they’re talking about.”

“Yeah.. wassup bro.”

“I have a question,” continued Keith, “When a judge is angry and stuff and you want to back down a bit but still want to save face… you know what I mean.. what do you do in such predicament?”

“I drop on the floor, belly up. Make the innocent face, and pee. Just a little. That’s what puppies do. Who can harm puppies?”

And Keith dropped belly up.
Continue Reading

Published on: October 12, 2015November 17, 2015 Author: SJD
Follow

### Follow “Fight © Trolls ”

Get every new post delivered to your Inbox.

Join 5,977 other followers

Build a website with WordPress.com
Post to
Cancel